@@ -9,13 +9,11 @@
 
 /// \file work/loops.h
 #include "pxr/pxr.h"
-#include "pxr/base/work/threadLimits.h"
 #include "pxr/base/work/api.h"
+#include "pxr/base/work/impl.h"
+#include "pxr/base/work/threadLimits.h"
 
-#include <tbb/blocked_range.h>
-#include <tbb/parallel_for.h>
-#include <tbb/parallel_for_each.h>
-#include <tbb/task_group.h>
+#include <algorithm>
 
 PXR_NAMESPACE_OPEN_SCOPE
 
@@ -62,32 +60,8 @@ WorkParallelForN(size_t n, Fn &&callback, size_t grainSize)
 
     // Don't bother with parallel_for, if concurrency is limited to 1.
     if (WorkHasConcurrency()) {
-
-        class Work_ParallelForN_TBB 
-        {
-        public:
-            Work_ParallelForN_TBB(Fn &fn) : _fn(fn) { }
-
-            void operator()(const tbb::blocked_range<size_t> &r) const {
-                // Note that we std::forward _fn using Fn in order get the
-                // right operator().
-                // We maintain the right type in this way:
-                //  If Fn is T&, then reference collapsing gives us T& for _fn 
-                //  If Fn is T, then std::forward correctly gives us T&& for _fn
-                std::forward<Fn>(_fn)(r.begin(), r.end());
-            }
-
-        private:
-            Fn &_fn;
-        };
-
-        // In most cases we do not want to inherit cancellation state from the
-        // parent context, so we create an isolated task group context.
-        tbb::task_group_context ctx(tbb::task_group_context::isolated);
-        tbb::parallel_for(tbb::blocked_range<size_t>(0,n,grainSize),
-            Work_ParallelForN_TBB(callback),
-            ctx);
-
+        PXR_WORK_IMPL_NAMESPACE_USING_DIRECTIVE;
+        WorkImpl_ParallelForN(n, std::forward<Fn>(callback), grainSize);
     } else {
 
         // If concurrency is limited to 1, execute serially.
@@ -132,8 +106,12 @@ inline void
 WorkParallelForEach(
     InputIterator first, InputIterator last, Fn &&fn)
 {
-    tbb::task_group_context ctx(tbb::task_group_context::isolated);
-    tbb::parallel_for_each(first, last, std::forward<Fn>(fn), ctx);
+    if (WorkHasConcurrency()) {
+        PXR_WORK_IMPL_NAMESPACE_USING_DIRECTIVE;
+        WorkImpl_ParallelForEach(first, last, std::forward<Fn>(fn));
+    } else {
+        std::for_each(first, last, std::forward<Fn>(fn));
+    }
 }
 
 PXR_NAMESPACE_CLOSE_SCOPE
